![Dugongo](https://raw.githubusercontent.com/fabianomenegidio/dugongo/master/dugongo.png)


# Dugong - Scientific Linux Container

[Dugong](https://hub.docker.com/r/bigscience/dugongo/) is a Linux container specifically designed for enabling open science. It is a free and open source operating system based on Ubuntu 15.10. Dugong is the junction of two softwares: Docker container and a Linux operating system.

***Docker*** is an open-source project that automates the deployment of applications inside software containers, by providing an additional layer of abstraction and automation of operating-system-level virtualization on Linux. Docker uses the resource isolation features of the Linux kernel such as cgroups and kernel namespaces, and a union-capable filesystem such as aufs and others to allow independent "containers" to run within a single Linux instance, avoiding the overhead of starting and maintaining virtual machines.

### List of Linux distributions:

***Ubuntu*** is a Debian-based Linux operating system and distribution for personal computers, smartphones and network servers. The Ubuntu project is publicly committed to the principles of open-source software development; people are encouraged to use free software, study how it works, improve upon it, and distribute it. 

### Graphical user interface (GUI)

***Xfce4*** (pronounced as four individual letters) is a free and open-source desktop environment for Unix and Unix-like platforms, such as Linux, Solaris, and BSD. Xfce aims to be fast and lightweight, while still being visually appealing and easy to use.

### Linuxbrew

Linuxbrew is a fork of Homebrew, the Mac OS package manager, for Linux. Features, usage and installation instructions are summarised on the [homepage](https://github.com/Linuxbrew/linuxbrew).

Features:

- Can install software to a home directory and so does not require sudo
- Install software not packaged by the native distribution
- Install up-to-date versions of software when the native distribution is old
- Use the same package manager to manage both your Mac and Linux machines

Linuxbrew is maintained by Shaun Jackman.

### Homebrew Science

Homebrew Science is a fork of homebrew focused on scientific softwares.

To install the softwares:
 install homebrew/science/<software> 

```bash
brew install homebrew/science/<software> 
```

or

```bash 
brew tap homebrew/science
brew install <software> 
```

A list of available software can be found below:

https://github.com/Homebrew/homebrew-science

### Conda

Conda is an open source package management system and environment management system for installing multiple versions of software packages and their dependencies and switching easily between them. It works on Linux, OS X and Windows, and was created for Python programs but can package and distribute any software.

Bioconda is a channel for the conda package manager specializing in bioinformatics software. Bioconda consists of:

- a repository of recipes hosted on GitHub
- a build system that turns these recipes into conda packages
- a repository of >1500 bioinformatics packages ready to use with conda install
- Over 130 contributors that add, modify, update and maintain the recipes

So any packages on the bioconda channel can be installed into the current conda environment:

```bash
conda install bwa
```

Or a new environment can be created:

```bash
conda create -n aligners bwa bowtie hisat star
```

Browse the packages to see what’s available: 

https://bioconda.github.io/recipes.html#recipes

### Software Packages

***VNC -*** is a graphical desktop sharing system that uses the Remote Frame Buffer protocol (RFB) to remotely control another computer. It transmits the keyboard and mouse events from one computer to another, relaying the graphical screen updates back in the other direction, over a network.

***noVNC -*** is a browser based VNC client implemented using HTML5 Canvas and WebSockets. You will either need a VNC server with WebSockets support (such as libvncserver) or you will need to use websockify to bridge between your browser and VNC server.

***MEGASync -*** is a desktop client for MEGA Cloud Service providing awesome features with  easy automated synchronization of files and folders between our computer and the cloud drive. 

***Google Chrome -*** is a browser that combines a minimal design with sophisticated technology to make the web faster, safer, and easier. 

***Mozilla Firefox -*** is a free and open-source web browser developed by the Mozilla Foundation and its subsidiary, the Mozilla Corporation.

### Images

Dugong - VNC access:

![Dugong](http://i.imgur.com/r9LdKlx.png)

Dugong - Web VNC access (noVNC) and Linuxbrew:

![Dugong](http://i.imgur.com/r6X6Lxa.png)


## Getting started:

Docker run on Linux, Cloud, Windows, and MacOS platforms. To install Docker, see Docker Docs: https://docs.docker.com

Automated builds of the image Dugong are available on [Dockerhub](https://hub.docker.com/r/bigscience/avida/) and is the recommended method of installation.

Pull a Dugong container:

```bash
docker pull bigscience/dugong
```

Start a Dugong container:

```bash
docker run -d -p 5901:5901 -p 6901:6901 \
--name dugong -h dugong --privileged bigscience/dugong
```

Access to Dugong container by noVNC:

```
http://<IP or Host>:<port>/vnc_auto.html?password=vncpassword
```


### Contributing

You are invited to contribute new features, fixes, or updates, large or small; we are always thrilled to receive pull requests, and do our best to process them as fast as we can.

Before you start to code, we recommend discussing your plans through a GitHub issue, especially for more ambitious contributions. This gives other contributors a chance to point you in the right direction, give you feedback on your design, and help you find out if someone else is working on the same thing.

### Author

Current development is led by Fabiano Menegidio.

### Learn More

![Dugong](https://raw.githubusercontent.com/fabianomenegidio/dugongo/master/dugongo_qrcode.png)
